Installation
============

From source
-----------
To install the latest release from PyPI, use ``pip`` inside a virtual environment

.. code-block:: console

    pip install pyscal


For contributing to pyscal and access to latest bleeding code, do

.. code-block:: console

    git clone https://github.com/equinor/pyscal
    pushd pyscal
    pip install .


Internally in Equinor
---------------------

pyscal is distributed through Komodo_.

.. _Komodo: https://fmu-docs.equinor.com/docs/komodo/equinor_komodo_usage.html
